@@ -1,5 +1,5 @@
 
-__version__ = '0.0.8'
+__version__ = '0.0.9'
 
 import numpy as np
 import pandas as pd
@@ -7,6 +7,7 @@ from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn import cross_validation
 from sklearn import grid_search
 
+
 def cross_val_score(model, X, *args, **kwargs):
     X = DataWrapper(X)
     return cross_validation.cross_val_score(model, X, *args, **kwargs)
@@ -29,6 +30,7 @@ try:
 except AttributeError:
     pass
 
+
 class DataWrapper(object):
     def __init__(self, df):
         self.df = df
@@ -40,6 +42,14 @@ class DataWrapper(object):
         return self.df.iloc[key]
 
 
+class PassthroughTransformer(TransformerMixin):
+    def fit(self, X, y=None, **fit_params):
+        return self
+
+    def transform(self, X):
+        return np.array(X).astype(np.float)
+
+
 class DataFrameMapper(BaseEstimator, TransformerMixin):
     '''
     Map Pandas data frame column subsets to their own
@@ -68,7 +78,9 @@ class DataFrameMapper(BaseEstimator, TransformerMixin):
 
         Returns a numpy array with the data from the selected columns
         '''
+        return_vector = False
         if isinstance(cols, basestring):
+            return_vector = True
             cols = [cols]
 
         if isinstance(X, list):
@@ -79,7 +91,7 @@ class DataFrameMapper(BaseEstimator, TransformerMixin):
             # if it's a datawrapper, unwrap it
             X = X.df
 
-        if len(cols) == 1:
+        if return_vector:
             t = X[cols[0]]
         else:
             t = X.as_matrix(cols)
